@@ -1,13 +1,13 @@
-import pytest
-import pandas as pd
 import numpy as np
+import pandas as pd
+import pytest
 from pandas._testing import assert_frame_equal
 
-from webviz_subsurface.plugins._well_completions import (
+from webviz_subsurface._datainput.well_completions import remove_invalid_colors
+from webviz_subsurface.plugins._well_completions._business_logic import (
     extract_stratigraphy,
     merge_compdat_and_connstatus,
 )
-from webviz_subsurface._datainput.well_completions import remove_invalid_colors
 
 
 def test_remove_invalid_colors():
