@@ -1,11 +1,10 @@
 import json
 import pathlib
 import warnings
-from typing import Optional
+from typing import Optional, Tuple, cast
 
 import pandas as pd
 
-
 _DATA_PATH = pathlib.Path(__file__).parent.absolute() / "abbreviation_data"
 
 SIMULATION_VECTOR_TERMINOLOGY = json.loads(
@@ -28,18 +27,18 @@ def simulation_unit_reformat(ecl_unit: str, unit_set: str = "METRIC") -> str:
 
 def simulation_vector_base(vector: str) -> str:
     """Returns base name of a simulation vector on Eclipse format.
-     E.g. WOPR for WOPR:OP_1 and ROIP for ROIP_REG:1.
-     Some description: If a vector contains a :, the first up to 5 characters describe the vector
-     base. In that case, if the vector base name is shorter than 5 characters, _ is used to fill
-     up the first five characters. Therefore splitting on first _ and limiting to max five
-     characters to identify the base name.
+    E.g. WOPR for WOPR:OP_1 and ROIP for ROIP_REG:1.
+    Some description: If a vector contains a :, the first up to 5 characters describe the vector
+    base. In that case, if the vector base name is shorter than 5 characters, _ is used to fill
+    up the first five characters. Therefore splitting on first _ and limiting to max five
+    characters to identify the base name.
     """
     return vector.split(":", 1)[0].split("_", 1)[0][:5] if ":" in vector else vector
 
 
 def simulation_vector_description(vector: str) -> str:
     """Returns a more human friendly description of the simulation vector if possible,
-     otherwise returns the input as is.
+    otherwise returns the input as is.
     """
     if vector.startswith("AVG_"):
         prefix = "Average "
@@ -49,7 +48,15 @@ def simulation_vector_description(vector: str) -> str:
         vector = vector[6:]
     else:
         prefix = ""
-    [vector_name, node] = vector.split(":", 1) if ":" in vector else [vector, None]
+
+    vector_name: str
+    node: Optional[str]
+    if ":" in vector:
+        [vector_name, node] = vector.split(":", 1)
+    else:
+        vector_name = vector
+        node = None
+
     if len(vector_name) == 8:
         if vector_name[0] == "R":
             # Region vectors for other FIP regions than FIPNUM are written on a special form:
@@ -106,7 +113,7 @@ def historical_vector(
     vector: str,
     smry_meta: Optional[pd.DataFrame] = None,
     return_historical: Optional[bool] = True,
-):
+) -> Optional[str]:
     """This function is trying to make a best guess on converting between historical and
     non-historical vector names.
 
@@ -146,16 +153,22 @@ def historical_vector(
     return parts[0][:-1] if is_hist else None
 
 
-def simulation_region_vector_breakdown(vector):
+def simulation_region_vector_breakdown(
+    vector: str,
+) -> Tuple[str, Optional[str], Optional[str]]:
     [vector_base_name, node, fip] = _vector_breakdown(vector)
     if fip is not None and len(fip) == 3:
         fiparray = f"FIP{fip}"
+    elif fip is not None:
+        fiparray = cast(str, fip)
     else:
-        fiparray = fip
+        fiparray = ""
     return vector_base_name, fiparray, node
 
 
-def simulation_region_vector_recompose(vector_base_name, fiparray, node):
+def simulation_region_vector_recompose(
+    vector_base_name: str, fiparray: str, node: str
+) -> str:
     return (
         vector_base_name
         + (
@@ -167,8 +180,15 @@ def simulation_region_vector_recompose(vector_base_name, fiparray, node):
     )
 
 
-def _vector_breakdown(vector):
-    [vector_name, node] = vector.split(":", 1) if ":" in vector else [vector, None]
+def _vector_breakdown(vector: str) -> Tuple[str, Optional[str], Optional[str]]:
+    vector_name: str
+    node: Optional[str]
+    fip: Optional[str]
+    if ":" in vector:
+        [vector_name, node] = vector.split(":", 1)
+    else:
+        vector_name = vector
+        node = None
     if len(vector_name) == 8:
         # Region vectors for other FIP regions than FIPNUM are written on a special form:
         # 8 signs, with the last 3 defining the region.
