@@ -1,13 +1,12 @@
 import json
 import pathlib
 
-
 _DATA_PATH = pathlib.Path(__file__).parent.absolute() / "abbreviation_data"
 
 VOLUME_TERMINOLOGY = json.loads((_DATA_PATH / "volume_terminology.json").read_text())
 
 
-def volume_description(column: str):
+def volume_description(column: str) -> str:
     """Return description for the column if defined"""
     try:
         label = VOLUME_TERMINOLOGY[column]["label"]
@@ -16,7 +15,7 @@ def volume_description(column: str):
     return label
 
 
-def volume_unit(column: str):
+def volume_unit(column: str) -> str:
     """Return unit for the column if defined"""
     try:
         unit = VOLUME_TERMINOLOGY[column]["unit"]
@@ -25,7 +24,7 @@ def volume_unit(column: str):
     return unit
 
 
-def volume_simulation_vector_match(column: str):
+def volume_simulation_vector_match(column: str) -> list:
     """Return a list of simulation vectors that match the column
     Useful to verify/propose data to compare.
     """
