@@ -1,5 +1,6 @@
 from typing import Dict, List, Union
 
+import numpy as np
 import pandas as pd
 
 
@@ -23,7 +24,7 @@ class TornadoData:
         if cutbyref:
             self._cut_sensitivities_by_ref()
         self._sort_sensitivities_by_max()
-        self._real_df = dframe[["REAL", "VALUE"]]
+        self._real_df = self._create_real_df(dframe)
 
     def _validate_input(self, dframe: pd.DataFrame) -> None:
         for col in self.REQUIRED_COLUMNS:
@@ -43,6 +44,29 @@ class TornadoData:
         if dframe.loc[dframe["SENSNAME"].isin([self._reference])].empty:
             raise ValueError(f"Reference SENSNAME {self._reference} not in input data")
 
+    def _create_real_df(self, dframe: pd.DataFrame) -> pd.DataFrame:
+        """Make dataframe with value and case info per realization"""
+        realdf = dframe[self.REQUIRED_COLUMNS].rename(
+            columns={"SENSNAME": "sensname", "SENSCASE": "senscase"}
+        )
+
+        sensitivities = self._tornadotable["sensname"].unique()
+        realdf = realdf.loc[realdf["sensname"].isin(sensitivities)]
+
+        for val in self.low_high_realizations_list.values():
+            for case in ["high", "low"]:
+                casemask = realdf["REAL"].isin(val[f"real_{case}"])
+                realdf.loc[casemask, "case"] = case
+
+        mc_mask = realdf["SENSTYPE"] == "mc"
+        realdf["casetype"] = np.where(mc_mask, "mc", realdf["case"])
+        realdf["sensname_case"] = np.where(
+            mc_mask,
+            realdf["sensname"],
+            realdf[["sensname", "senscase"]].agg("--".join, axis=1),
+        )
+        return realdf
+
     @property
     def real_df(self) -> pd.DataFrame:
         return self._real_df
@@ -83,10 +107,9 @@ class TornadoData:
         avg_per_sensitivity = []
 
         for sens_name, sens_name_df in dframe.groupby(["SENSNAME"]):
-            # Excluding the reference case as well as any cases named `ref`
-            # `ref` is used as `SENSNAME`, typically for a single realization only,
-            # when no seed uncertainty is used
-            if sens_name == "ref":
+            # Excluding cases if `ref` is used as `SENSNAME`, and only one realization
+            # is present for this `SENSNAME`
+            if sens_name == "ref" and len(sens_name_df["REAL"].unique()) == 1:
                 continue
 
             # If `SENSTYPE` is scalar get the mean for each `SENSCASE`
@@ -210,6 +233,7 @@ class TornadoData:
 
         self._tornadotable = self._tornadotable.loc[
             ((self._tornadotable["low"] - self._tornadotable["high"]) != 0)
+            | (self._tornadotable["sensname"] == self._reference)
         ]
 
     def _sort_sensitivities_by_max(self) -> None:
