@@ -1,18 +1,14 @@
-from typing import List, Dict, Optional
 from pathlib import Path
+from typing import Dict, List, Optional
 
 import numpy as np
 import pandas as pd
 import plotly.express as px
 import plotly.graph_objs as go
-import dash_table
-import dash_html_components as html
-import dash_core_components as dcc
 import webviz_core_components as wcc
-from dash.dependencies import Input, Output
+from dash import Dash, Input, Output, dash_table, dcc, html
 from dash.exceptions import PreventUpdate
-from webviz_config import WebvizPluginABC
-from webviz_config import WebvizSettings
+from webviz_config import WebvizPluginABC, WebvizSettings
 from webviz_config.common_cache import CACHE
 from webviz_config.webviz_store import webvizstore
 
@@ -49,7 +45,7 @@ class AssistedHistoryMatchingAnalysis(WebvizPluginABC):
 
     def __init__(
         self,
-        app,
+        app: Dash,
         webviz_settings: WebvizSettings,
         input_dir: Path,
         ks_filter: float = 0.0,
@@ -264,6 +260,7 @@ class AssistedHistoryMatchingAnalysis(WebvizPluginABC):
             Output(self.uuid("click_data"), component_property="children"),
             Input(self.uuid("heatmap_id"), component_property="clickData"),
             Input(self.uuid("choice_hist_id"), component_property="value"),
+            prevent_initial_call=True,
         )
         def _display_click_data(celldata, hist_display):
             """render a histogram of parameters distribution prior/posterior or
@@ -339,11 +336,7 @@ class AssistedHistoryMatchingAnalysis(WebvizPluginABC):
                 get_path(self.input_dir / "misfit_obs_info.csv"), index_col=0
             )
             list_ok = list(misfit_info.filter(like="All_obs", axis=1).columns)
-            listtoplot = [
-                ele
-                for ele in misfit_info.columns  # PyCQA/pylint#4577 # pylint: disable=no-member
-                if ele not in list_ok
-            ]
+            listtoplot = [ele for ele in misfit_info.columns if ele not in list_ok]
             if choiceplot == "ALL":
                 listtoplot = list_ok
             active_info = read_csv(
