@@ -1,8 +1,7 @@
-from typing import Union, Optional, Callable
+from typing import Callable, Optional, Union
 
-import dash_html_components as html
-import dash_core_components as dcc
 import webviz_core_components as wcc
+from dash import dcc, html
 
 from ..figures.color_figure import color_figure
 from ..models import ParametersModel, SimulationTimeSeriesModel
@@ -10,26 +9,21 @@ from ..models import ParametersModel, SimulationTimeSeriesModel
 
 def ensemble_selector(
     get_uuid: Callable,
-    parametermodel: ParametersModel,
+    ensembles: list,
     tab: str,
     id_string: str,
     multi: bool = False,
     value: str = None,
     heading: str = None,
 ) -> html.Div:
-    children = []
-
-    children.append(
-        wcc.Dropdown(
-            label=heading,
-            id={"id": get_uuid(id_string), "tab": tab},
-            options=[{"label": ens, "value": ens} for ens in parametermodel.ensembles],
-            multi=multi,
-            value=value if value is not None else parametermodel.ensembles[0],
-            clearable=False,
-        )
+    return wcc.Dropdown(
+        label=heading,
+        id={"id": get_uuid(id_string), "tab": tab},
+        options=[{"label": ens, "value": ens} for ens in ensembles],
+        multi=multi,
+        value=value if value is not None else ensembles[0],
+        clearable=False,
     )
-    return html.Div(style={"width": "90%"}, children=children)
 
 
 def vector_selector(
@@ -41,13 +35,13 @@ def vector_selector(
         else list(vectormodel.vector_groups.keys())[0]
     )
     return html.Div(
-        style={"width": "90%"},
+        style={"margin": "10px 0px"},
         children=[
             html.Span(wcc.Label("Vector type")),
             html.Div(
                 id=get_uuid("vtype-container"),
                 children=[
-                    dcc.RadioItems(
+                    wcc.RadioItems(
                         id={"id": get_uuid("vtype-select"), "state": "initial"},
                         options=[
                             {"label": i, "value": i} for i in vectormodel.vector_groups
@@ -137,9 +131,8 @@ def plot_options(get_uuid: Callable, tab: str) -> html.Div:
                 ],
                 value=["DateLine", "AutoCompute"],
             ),
-            html.Div(
-                id={"id": get_uuid("plot-options"), "tab": tab},
-                style={"display": "none"},
+            dcc.Store(
+                id={"id": get_uuid("plot-options"), "tab": tab}, storage_type="session"
             ),
         ],
     )
@@ -150,17 +143,21 @@ def date_selector(
 ) -> html.Div:
     dates = vectormodel.dates
     return html.Div(
+        style={"margin": "10px 0px"},
         children=[
             html.Div(
                 style={"display": "inline-flex"},
                 children=[
-                    html.Span(wcc.Label("Date:")),
-                    html.Span(
-                        html.Label(
-                            "date",
-                            id=get_uuid("date-selected"),
-                            style={"margin-left": "10px"},
-                        ),
+                    wcc.Label("Date:"),
+                    wcc.Label(
+                        dates[len(dates) - 1],
+                        id=get_uuid("date-selected-text"),
+                        style={"margin-left": "10px"},
+                    ),
+                    dcc.Store(
+                        id=get_uuid("date-selected"),
+                        storage_type="session",
+                        data=dates[len(dates) - 1],
                     ),
                 ],
             ),
@@ -192,7 +189,7 @@ def filter_parameter(
     value: Union[str, float] = None,
 ) -> html.Div:
     return html.Div(
-        style={"margin-top": "10px", "width": "90%"},
+        style={"margin-top": "10px"},
         children=[
             wcc.Label("Select parameters"),
             html.Div(
@@ -225,11 +222,11 @@ def make_filter(
     value: Union[str, float] = None,
     open_details: bool = False,
 ) -> wcc.Selectors:
-    return wcc.Selectors(
-        label=vtype,
+    return html.Details(
         open=open_details,
         children=[
-            wcc.SelectWithLabel(
+            html.Summary(vtype),
+            wcc.Select(
                 id={
                     "id": get_uuid("vitem-filter"),
                     "tab": tab,
@@ -253,7 +250,7 @@ def filter_vector_selector(
     open_details: bool = False,
 ) -> html.Div:
     return html.Div(
-        style={"width": "90%"},
+        style={"margin-top": "10px"},
         children=[
             wcc.Dropdown(
                 label="Vector type",
@@ -268,6 +265,7 @@ def filter_vector_selector(
                 multi=True,
             ),
             html.Div(
+                style={"margin-top": "10px"},
                 children=[
                     make_filter(
                         get_uuid=get_uuid,
@@ -298,7 +296,7 @@ def color_selector(
     height: Optional[float] = None,
 ):
     return html.Div(
-        style={"width": "90%", "margin-top": "5px"},
+        style={"margin-top": "5px"},
         children=[
             wcc.Label("Colors"),
             wcc.Graph(
@@ -316,7 +314,7 @@ def color_selector(
 
 def color_opacity_selector(get_uuid: Callable, tab: str, value: float):
     return html.Div(
-        style={"width": "90%", "margin-top": "5px"},
+        style={"margin-top": "5px"},
         children=[
             "Opacity:",
             dcc.Input(
