@@ -1,7 +1,7 @@
-from typing import Union, Callable, List
+from typing import Callable, List, Union
 
-import dash_html_components as html
 import webviz_core_components as wcc
+from dash import html
 
 from ..models import PropertyStatisticsModel
 
