@@ -1,27 +1,25 @@
-# pylint: disable=too-many-lines
-from typing import Optional, Union
 import warnings
 from pathlib import Path
+from typing import Optional, Union
 
 import numpy as np
-import dash_core_components as dcc
-from dash.dependencies import Input, Output, State
-from dash.exceptions import PreventUpdate
 import webviz_core_components as wcc
-from webviz_config.webviz_assets import WEBVIZ_ASSETS
+from dash import Input, Output, State, dcc
+from dash.exceptions import PreventUpdate
+from webviz_config import WebvizPluginABC, WebvizSettings
 from webviz_config.common_cache import CACHE
-from webviz_config import WebvizPluginABC
-from webviz_config import WebvizSettings
+from webviz_config.webviz_assets import WEBVIZ_ASSETS
 
 import webviz_subsurface
-from .._datainput.relative_permeability import load_satfunc, load_scal_recommendation
+
 from .._datainput.fmu_input import load_csv
+from .._datainput.relative_permeability import load_satfunc, load_scal_recommendation
 from .._utils.fanchart_plotting import (
     FanchartData,
-    get_fanchart_traces,
     FreeLineData,
-    MinMaxData,
     LowHighData,
+    MinMaxData,
+    get_fanchart_traces,
 )
 
 
@@ -126,7 +124,6 @@ webviz-subsurface-testdata/blob/master/reek_history_match/share/scal/scalreek.cs
                     "There has to be a KEYWORD or TYPE column with corresponding Eclipse keyword: "
                     "e.g SWOF, SGOF and etc."
                 )
-            # pylint: disable=literal-comparison
             valid_columns = (
                 ["ENSEMBLE", "REAL", "KEYWORD", "SATNUM"]
                 + RelativePermeability.SATURATIONS
@@ -206,7 +203,6 @@ webviz-subsurface-testdata/blob/master/reek_history_match/share/scal/scalreek.cs
         self.set_callbacks(app)
 
     @property
-    # pylint: disable=consider-iterating-dictionary
     def sat_axes(self):
         """List of all possible saturation axes in dataframe"""
         return [sat for sat in self.sat_axes_maps if sat in self.satfunc.columns]
@@ -825,7 +821,7 @@ def _get_fanchart_traces(
 
     return get_fanchart_traces(
         data=data,
-        color=color,
+        hex_color=color,
         legend_group=legend_group,
         xaxis=xaxis,
         yaxis=yaxis,
