@@ -1,40 +1,36 @@
-from typing import List, Tuple, Callable, Union
-from pathlib import Path
-from uuid import uuid4
-import json
 import datetime
+import json
+from pathlib import Path
+from typing import Callable, List, Tuple, Union
+from uuid import uuid4
 
 import numpy as np
 import pandas as pd
-import dash
-from dash.exceptions import PreventUpdate
-from dash.dependencies import Input, Output, State
-import dash_html_components as html
-import dash_core_components as dcc
-from dash_table import DataTable
 import webviz_core_components as wcc
-from webviz_config import WebvizPluginABC
-from webviz_config import WebvizSettings
+from dash import Dash, Input, Output, State, callback_context, dash_table, dcc, html
+from dash.exceptions import PreventUpdate
+from webviz_config import WebvizPluginABC, WebvizSettings
 from webviz_config.common_cache import CACHE
 from webviz_config.webviz_store import webvizstore
 
-from webviz_subsurface._models import EnsembleSetModel
-from webviz_subsurface._models import caching_ensemble_set_model_factory
 from webviz_subsurface._components import TornadoWidget
-from .._datainput.fmu_input import (
-    get_realizations,
-    find_sens_type,
-)
-from .._abbreviations.reservoir_simulation import (
-    simulation_vector_description,
-    simulation_unit_reformat,
-    historical_vector,
+from webviz_subsurface._models import (
+    EnsembleSetModel,
+    caching_ensemble_set_model_factory,
 )
+
 from .._abbreviations.number_formatting import table_statistics_base
-from .._utils.simulation_timeseries import (
-    set_simulation_line_shape_fallback,
-    get_simulation_line_shape,
+from .._abbreviations.reservoir_simulation import (
+    historical_vector,
+    simulation_unit_reformat,
+    simulation_vector_description,
 )
+from .._datainput.fmu_input import find_sens_type, get_realizations
+from .._utils.simulation_timeseries import (
+    get_simulation_line_shape,
+    set_simulation_line_shape_fallback,
+)
+
 
 # pylint: disable=too-many-instance-attributes
 class ReservoirSimulationTimeSeriesOneByOne(WebvizPluginABC):
@@ -124,7 +120,7 @@ folder, to avoid risk of not extracting the right data.
     # pylint: disable=too-many-arguments
     def __init__(
         self,
-        app: dash.Dash,
+        app: Dash,
         webviz_settings: WebvizSettings,
         csvfile_smry: Path = None,
         csvfile_parameters: Path = None,
@@ -183,8 +179,7 @@ folder, to avoid risk of not extracting the right data.
             c
             for c in self.smry.columns
             if c not in ReservoirSimulationTimeSeriesOneByOne.ENSEMBLE_COLUMNS
-            and historical_vector(c, self.smry_meta, False)
-            not in self.smry.columns  # PyCQA/pylint#4577 # pylint: disable=no-member
+            and historical_vector(c, self.smry_meta, False) not in self.smry.columns
         ]
         self.initial_vector = (
             initial_vector
@@ -339,7 +334,7 @@ folder, to avoid risk of not extracting the right data.
                                     ),
                                     html.Div(
                                         style={"fontSize": "15px"},
-                                        children=DataTable(
+                                        children=dash_table.DataTable(
                                             id=self.ids("table"),
                                             sort_action="native",
                                             filter_action="native",
@@ -366,7 +361,7 @@ folder, to avoid risk of not extracting the right data.
         )
 
     # pylint: disable=too-many-statements
-    def set_callbacks(self, app: dash.Dash) -> None:
+    def set_callbacks(self, app: Dash) -> None:
         @app.callback(
             [
                 # Output(self.ids("date-store"), "children"),
@@ -441,9 +436,9 @@ folder, to avoid risk of not extracting the right data.
             figure: dict,
         ) -> dict:
             """Update graph with line coloring, vertical line and title"""
-            if dash.callback_context.triggered is None:
+            if callback_context.triggered is None:
                 raise PreventUpdate
-            ctx = dash.callback_context.triggered[0]["prop_id"].split(".")[0]
+            ctx = callback_context.triggered[0]["prop_id"].split(".")[0]
 
             tornado_click: Union[dict, None] = (
                 json.loads(tornado_click_data_str) if tornado_click_data_str else None
