@@ -1336,7 +1336,7 @@ def _get_fanchart_traces(
 
     return get_fanchart_traces(
         data=data,
-        color=color,
+        hex_color=color,
         legend_group=legend_group,
         line_shape=line_shape,
         hovertext=hovertemplate,
