@@ -1,11 +1,10 @@
-from typing import Dict, Callable, Tuple, Union, List
+from typing import Callable, Dict, List, Tuple, Union
 
-import dash
-from dash.dependencies import Input, Output, MATCH
+from dash import MATCH, Dash, Input, Output
 
 
 def update_intersection_source(
-    app: dash.Dash, get_uuid: Callable, surface_geometry: Dict
+    app: Dash, get_uuid: Callable, surface_geometry: Dict
 ) -> None:
     @app.callback(
         Output(
