@@ -1,5 +1,5 @@
-from typing import List, Dict, Any
 from pathlib import Path
+from typing import Any, Dict, List
 
 import yaml
 
